Struct realpath_ext::RealpathRawBuilder
source · [−]pub struct RealpathRawBuilder<'a> { /* private fields */ }Expand description
A “builder” that allows customizing options to realpath_raw().
realpath_raw(path, buf, flags) is equivalent to
RealpathRawBuilder::new().flags(flags).realpath_raw(path, buf).
Implementations
Create a new “builder”.
The returned builder has its flags empty, and temp_buffer set to None.
Set the flags used to modify path resolution.
See RealpathFlags for more information.
Set the temporary buffer used to store intermediate results.
It’s recommended to make this buffer somewhat larger than the buf passed to
Self::realpath_raw(), since the current algorithm requires a bit of overhead in the
temporary buffer.
If tmp is None (default), a temporary buffer of length PATH_MAX + 100 will be
allocated on the stack.