Struct realpath_ext::RealpathBuilder
source · [−]pub struct RealpathBuilder { /* private fields */ }Expand description
A “builder” that allows customizing options to realpath_raw().
realpath(path, flags) is equivalent to RealpathBuilder::new().flags(flags).realpath(path).
Implementations
Create a new “builder”.
The returned builder has its flags empty. max_size will be set to 32768 on WASI, and
PATH_MAX on other OSes.
Set the maximum path length allowed before failing with ENAMETOOLONG.
Generally speaking, this is only useful if the OS supports paths longer than PATH_MAX (for
example, this is the case on WASI).
Note: In some cases, Self::realpath() may allocate a smaller buffer than this length,
then expand it and retry if resolution fails with ENAMETOOLONG.
Set the flags used to modify path resolution.
See RealpathFlags for more information.